==> sso-api-1.0.25-20170712.083934-2-sources.jar: cn/com/duiba/sso/api/web/tool/RequestTool.java <==
package cn.com.duiba.sso.api.web.tool;

import java.lang.ref.SoftReference;
import java.util.*;
import java.util.concurrent.ConcurrentHashMap;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import cn.com.duiba.sso.api.domain.dto.AdminDto;
import cn.com.duiba.sso.api.domain.dto.PermissionDto;
import cn.com.duiba.sso.api.domain.enums.SystemEnum;
import cn.com.duiba.sso.api.exception.SsoException;
import cn.com.duiba.sso.api.remoteservice.RemoteAdminService;
import cn.com.duiba.sso.api.remoteservice.RemotePermissionService;
import cn.com.duiba.sso.api.remoteservice.RemoteSSOService;
import cn.com.duiba.sso.api.web.factory.SsoContext;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.duiba.wolf.utils.BeanUtils;
import com.google.common.base.Objects;

import cn.com.duiba.sso.api.exception.SsoRunTimeException;
import org.apache.commons.lang3.StringUtils;

/**
 * Created by liuyao on 2017/5/11.
 */
public class RequestTool {
    private static ThreadLocal<RequestTool> local = new ThreadLocal<>();
    private static SsoContext context;
    private static RemoteAdminService remoteAdminService;
    private static RemotePermissionService remotePermissionService;
    private static RemoteSSOService remoteSSOService;
    private HttpServletRequest request;
    private HttpServletResponse response;
    private RequestParams params;



    public static void setRequestInThreadLocal(HttpServletRequest request, HttpServletResponse response){
        if(request==null) throw new SsoRunTimeException("RequestTool注入request为空");
        if(response==null) throw new SsoRunTimeException("RequestTool注入response为空");
        RequestTool tool = new RequestTool();
        tool.request = request;
        tool.response = response;
        tool.params = RequestParams.parse(request);
        local.set(tool);
    }

    public static void setSsoContext(SsoContext context){
        RequestTool.remoteAdminService = context.getBean(RemoteAdminService.class);
        RequestTool.remotePermissionService = context.getBean(RemotePermissionService.class);
        RequestTool.remoteSSOService = context.getBean(RemoteSSOService.class);
    }

    private static RequestTool get(){
        if(local.get()==null) throw new SsoRunTimeException("请在登录拦截器中调用setRequestInThreadLocal");
        return local.get();
    }

    /**
     * RequestTool中的变量只能在当前线程中使用,当启用异步线程的时候,使用此方法复制一个新的封装对象,防止空指针
     * @return
     */
    public static RequestParams getRequestParams(){
        return get().params.clone();
    }

    public static HttpServletResponse getResponse(){
        return get().response;
    }

    public static HttpServletRequest getRequest(){
        return get().request;
    }

    public static void removeRequestInThreadLocal(){
        local.remove();
    }

    public static Long getAdminId(){
        AdminDto admin = getAdmin();
        return admin.getId();
    }

    public static AdminDto getAdmin() {
        RequestTool tool = RequestTool.get();
        return tool.params.getAdmin();
    }

    public static void setAdmin(AdminDto admin) {
        RequestTool tool = RequestTool.get();
        tool.params.setAdmin(admin);
    }

    public static  List<AdminDto> GetAdmins(String roleName, SystemEnum system)throws RuntimeException{
        if(system == null){
            throw new IllegalArgumentException("system");
        }
        int systemId = system.getId().intValue();
        DubboResult<List<AdminDto>> result = RequestTool.remoteAdminService.findAdmins(systemId,roleName);
        return result.getResult();
    }

    public static AdminDto getAdmin(String ticket){
        DubboResult<AdminDto> result = RequestTool.remoteSSOService.verifyTicketToAdmin(ticket);
        return result.getResult();
    }

    public static void addCookie(Cookie cookie){
        if(cookie==null){
            return;
        }
        RequestTool tool = RequestTool.get();
        tool.params.addCookie(cookie.getName(),cookie.getValue());
        tool.response.addCookie(cookie);
    }

    public static String getUrl(){
        return get().params.getUrl();
    }

    public static boolean isHttpsRequest(){
        HttpServletRequest request= get().request;
        return "true".equals(request.getHeader("Use-Https"));
    }

    public static String getCookie(String name){
        RequestTool tool = RequestTool.get();
        return tool.params.getCookie(name);
    }

    /**
     * 提取request中的参数
     * @return
     */
    public static Map<String,String> getRequestParamMap(){
        HttpServletRequest request= get().request;
        Map<String, String[]> map=request.getParameterMap();
        Map<String, String> resultMap=new HashMap<>();
        for(Map.Entry<String, String[]> entry :map.entrySet()){
            resultMap.put(entry.getKey(), entry.getValue()[0]);
        }
        return resultMap;
    }

    public static Boolean isAsynchronousRequests(){
        HttpServletRequest request= get().request;
        String re = request.getHeader("x-requested-with");
        String accept = request.getHeader("Accept");
        return (StringUtils.isNoneBlank(re) || StringUtils.isNoneBlank(accept) && accept.contains("json"));
    }

    public static String getIp(){
        RequestTool tool = RequestTool.get();
        return tool.params.getIp();
    }

    public static Boolean isLocalHost(){
        RequestTool tool = RequestTool.get();
        return Objects.equal(tool.params.getIp(),RequestParams.LOCALHOST_IP);
    }

    public static void googleVerify(String code) throws SsoException{
        RequestTool tool = RequestTool.get();
        Long adminId = tool.getAdminId();
        DubboResult<Boolean> result = RequestTool.remoteAdminService.googleVerify(adminId,code);
        if(!result.isSuccess()){
            throw new SsoException(result.getMsg());
        }
    }

    public static List<PermissionDto> GetPermissions(Long adminId,Long systemId) throws RuntimeException{
        DubboResult<List<PermissionDto>> result = RequestTool.remotePermissionService.getPermissions(adminId.intValue(),systemId.intValue());
        List<PermissionDto> permissionDtoList = result.getResult();
        return permissionDtoList;
    }
    /**
     * 获取令牌
     * @return
     */
    public static String findTicket(){
        String ticketForUrl = getRequestParamMap().get(CookieUtil.LOGIN_COOKIE_NAME);
        if(StringUtils.isNotBlank(ticketForUrl)){
            return ticketForUrl;
        }
        return CookieUtil.getCookie(CookieUtil.LOGIN_COOKIE_NAME);
    }

    public static Set<String> getUrlBlackSet(int adminId,int systemId) throws SsoException {
        DubboResult<Set<String>> result = remotePermissionService.getUrlBlackSet(adminId,systemId);
        if(!result.isSuccess()){
            throw new SsoException(result.getMsg());
        }
        return result.getResult();

    }

    public static Set<String> getUrlWhiteSet(int adminId,int systemId) throws SsoException {
        DubboResult<Set<String>> result = remotePermissionService.getUrlWhiteSet(adminId,systemId);
        if(!result.isSuccess()){
            throw new SsoException(result.getMsg());
        }
        return result.getResult();
    }

    public static boolean outSsoLogin(String ticket,SystemEnum systemEnum){
        int systemId = systemEnum.getId().intValue();
        CookieUtil.deleteCookie(CookieUtil.LOGIN_COOKIE_NAME);
        remoteSSOService.removePermissionCache(ticket,systemId);
        return true;
    }


}

==> sso-api-1.0.44-20170802.044715-2-sources.jar: cn/com/duiba/sso/api/web/tool/RequestTool.java <==
package cn.com.duiba.sso.api.web.tool;

import java.lang.ref.SoftReference;
import java.util.*;
import java.util.concurrent.ConcurrentHashMap;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import cn.com.duiba.sso.api.domain.dto.AdminDto;
import cn.com.duiba.sso.api.domain.dto.PermissionDto;
import cn.com.duiba.sso.api.domain.enums.SystemEnum;
import cn.com.duiba.sso.api.exception.SsoException;
import cn.com.duiba.sso.api.remoteservice.RemoteAdminService;
import cn.com.duiba.sso.api.remoteservice.RemoteManagerLogService;
import cn.com.duiba.sso.api.remoteservice.RemotePermissionService;
import cn.com.duiba.sso.api.remoteservice.RemoteSSOService;
import cn.com.duiba.sso.api.web.factory.SsoContext;
import cn.com.duiba.sso.api.web.logger.domain.SsoLoggerParams;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.duiba.wolf.utils.BeanUtils;
import com.google.common.base.Objects;

import cn.com.duiba.sso.api.exception.SsoRunTimeException;
import org.apache.commons.lang3.StringUtils;

/**
 * Created by liuyao on 2017/5/11.
 */
public class RequestTool {
    private static ThreadLocal<RequestTool> local = new ThreadLocal<>();
    private static SsoContext context;
    private static RemoteAdminService remoteAdminService;
    private static RemotePermissionService remotePermissionService;
    private static RemoteSSOService remoteSSOService;
    private static RemoteManagerLogService remoteManagerLogService;
    private HttpServletRequest request;
    private HttpServletResponse response;
    private RequestParams params;



    public static void setRequestInThreadLocal(HttpServletRequest request, HttpServletResponse response){
        if(request==null) throw new SsoRunTimeException("RequestTool注入request为空");
        if(response==null) throw new SsoRunTimeException("RequestTool注入response为空");
        RequestTool tool = new RequestTool();
        tool.request = request;
        tool.response = response;
        tool.params = RequestParams.parse(request);
        local.set(tool);
    }

    public static void setSsoContext(SsoContext context){
        RequestTool.remoteAdminService = context.getBean(RemoteAdminService.class);
        RequestTool.remotePermissionService = context.getBean(RemotePermissionService.class);
        RequestTool.remoteSSOService = context.getBean(RemoteSSOService.class);
        RequestTool.remoteManagerLogService = context.getBean(RemoteManagerLogService.class);
    }

    private static RequestTool get(){
        if(local.get()==null) throw new SsoRunTimeException("请在登录拦截器中调用setRequestInThreadLocal");
        return local.get();
    }

    /**
     * RequestTool中的变量只能在当前线程中使用,当启用异步线程的时候,使用此方法复制一个新的封装对象,防止空指针
     * @return
     */
    public static RequestParams getRequestParams(){
        return get().params.clone();
    }

    public static HttpServletResponse getResponse(){
        return get().response;
    }

    public static HttpServletRequest getRequest(){
        return get().request;
    }

    public static void removeRequestInThreadLocal(){
        local.remove();
    }

    public static Long getAdminId(){
        AdminDto admin = getAdmin();
        return admin.getId();
    }

    public static AdminDto getAdmin() {
        RequestTool tool = RequestTool.get();
        AdminDto adminDto =  tool.params.getAdmin();
        if(adminDto == null){
            String ticket = RequestTool.findTicket();
            DubboResult<AdminDto> result = RequestTool.remoteSSOService.verifyTicketToAdmin(ticket);
            adminDto = result.getResult();
        }


        return adminDto;
    }

    public static void setAdmin(AdminDto admin) {
        RequestTool tool = RequestTool.get();
        tool.params.setAdmin(admin);
    }

    public static  List<AdminDto> getAdmins(String roleName, SystemEnum system)throws RuntimeException{
        if(system == null){
            throw new IllegalArgumentException("system");
        }
        int systemId = system.getId().intValue();
        DubboResult<List<AdminDto>> result = RequestTool.remoteAdminService.findAdmins(systemId,roleName);
        return result.getResult();
    }

    public static AdminDto getAdmin(String ticket){
        DubboResult<AdminDto> result = RequestTool.remoteSSOService.verifyTicketToAdmin(ticket);
        return result.getResult();
    }

    public static void addCookie(Cookie cookie){
        if(cookie==null){
            return;
        }
        RequestTool tool = RequestTool.get();
        tool.params.addCookie(cookie.getName(),cookie.getValue());
        tool.response.addCookie(cookie);
    }

    public static String getUrl(){
        return get().params.getUrl();
    }

    public static boolean isHttpsRequest(){
        HttpServletRequest request= get().request;
        return "true".equals(request.getHeader("Use-Https"));
    }

    public static String getCookie(String name){
        RequestTool tool = RequestTool.get();
        return tool.params.getCookie(name);
    }

    /**
     * 提取request中的参数
     * @return
     */
    public static Map<String,String> getRequestParamMap(){
        HttpServletRequest request= get().request;
        Map<String, String[]> map=request.getParameterMap();
        Map<String, String> resultMap=new HashMap<>();
        for(Map.Entry<String, String[]> entry :map.entrySet()){
            resultMap.put(entry.getKey(), entry.getValue()[0]);
        }
        return resultMap;
    }

    public static Boolean isAsynchronousRequests(){
        HttpServletRequest request= get().request;
        String re = request.getHeader("x-requested-with");
        String accept = request.getHeader("Accept");
        return (StringUtils.isNoneBlank(re) || StringUtils.isNoneBlank(accept) && accept.contains("json"));
    }

    public static String getIp(){
        RequestTool tool = RequestTool.get();
        return tool.params.getIp();
    }

    public static Boolean isLocalHost(){
        RequestTool tool = RequestTool.get();
        return Objects.equal(tool.params.getIp(),RequestParams.LOCALHOST_IP);
    }

    public static void googleVerify(String code) throws SsoException{
        RequestTool tool = RequestTool.get();
        Long adminId = tool.getAdminId();
        DubboResult<Boolean> result = RequestTool.remoteAdminService.googleVerify(adminId,code);
        if(!result.isSuccess()){
            throw new SsoException(result.getMsg());
        }
    }

    public static List<PermissionDto> GetPermissions(Long adminId,Long systemId) throws RuntimeException{
        DubboResult<List<PermissionDto>> result = RequestTool.remotePermissionService.getPermissions(adminId.intValue(),systemId.intValue());
        List<PermissionDto> permissionDtoList = result.getResult();
        return permissionDtoList;
    }
    /**
     * 获取令牌
     * @return
     */
    public static String findTicket(){
        String ticketForUrl = getRequestParamMap().get(CookieUtil.LOGIN_COOKIE_NAME);
        if(StringUtils.isNotBlank(ticketForUrl)){
            return ticketForUrl;
        }
        return CookieUtil.getCookie(CookieUtil.LOGIN_COOKIE_NAME);
    }

    public static Set<String> getUrlBlackSet(int adminId,int systemId) throws SsoException {
        DubboResult<Set<String>> result = remotePermissionService.getUrlBlackSet(adminId,systemId);
        if(!result.isSuccess()){
            throw new SsoException(result.getMsg());
        }
        return result.getResult();

    }

    public static Set<String> getUrlWhiteSet(int adminId,int systemId) throws SsoException {
        DubboResult<Set<String>> result = remotePermissionService.getUrlWhiteSet(adminId,systemId);
        if(!result.isSuccess()){
            throw new SsoException(result.getMsg());
        }
        return result.getResult();
    }

    public static boolean outSsoLogin(SystemEnum systemEnum){
        String ticket = RequestTool.findTicket();
        int systemId = systemEnum.getId().intValue();
        CookieUtil.deleteCookie(CookieUtil.LOGIN_COOKIE_NAME);
        remoteSSOService.removePermissionCache(ticket,systemId);
        remoteSSOService.removeTicket(ticket);
        return true;
    }

    public static boolean insertPermissions(int systemId,String permissionTree){
        DubboResult<Boolean> result = remotePermissionService.insertPermissions(systemId,permissionTree);
        return result.getResult();
    }

    public static void sendOperationLog(SsoLoggerParams ssoLoggerParams){
        remoteManagerLogService.log(ssoLoggerParams);
    }

}
